#!/bin/sh

## This is the main script called by OSTRICH (in ostIn.txt file as "ModelExecutable") to: 
##  1) prepare sub-directories and files needed to run the MESH model
##  2) Run the MESH model 
##  3) Calculate the metrics to be read back by OSTRICH
echo inside OST_MESH Script

## define the root directory where all directories reside
## or explicitly proviad the path name 
root_dir=../..

## specify the forcing data directory
dir_forcing=$root_dir/forcing

## Specify the common inputs data directory
dir_inputs=$root_dir/common_inputs

pwd
cp -n $root_dir/MESH_model/sa_mesh_r1037 ./sa_mesh_r1037
cp -n $root_dir/Scripts/run_mesh.sh ./run_mesh.sh

## Link (or copy) the forcing data
ln -s $dir_forcing/basin_rain.seq ./basin_rain.seq
ln -s $dir_forcing/basin_wind.seq ./basin_wind.seq
ln -s $dir_forcing/basin_humidity.seq ./basin_humidity.seq
ln -s $dir_forcing/basin_shortwave.seq ./basin_shortwave.seq
ln -s $dir_forcing/basin_longwave.seq ./basin_longwave.seq
ln -s $dir_forcing/basin_temperature.seq ./basin_temperature.seq
ln -s $dir_forcing/basin_pres.seq ./basin_pres.seq

## Link (or Copy) the common input files 
ln -s $dir_inputs/MESH_drainage_database.r2c ./MESH_drainage_database.r2c
ln -s $dir_inputs/MESH_input_streamflow.txt ./MESH_input_streamflow.txt
ln -s $dir_inputs/MESH_input_reservoir.txt ./MESH_input_reservoir.txt
ln -s $dir_inputs/MESH_input_soil_levels.txt ./MESH_input_soil_levels.txt
ln -s $dir_inputs/minmax_parameters.txt ./minmax_parameters.txt
cp -f $dir_inputs/BAD_Metrics_Out.txt ./BAD_Metrics_Out.txt 
cp -f $dir_inputs/MESH_input_run_options.ini ./MESH_input_run_options.ini

echo Running the MESH Model
## Remove previous metric file, if any
rm -f ./Metrics_Out.txt 

## Call the script to run the MESH model and calculate metrics.
## MESH caluates metrics internally and writes them into the Metrics_Out.txt file. Otherwise, a code is needed for this step.
## Metrics_Out.txt is the file that is read back by OSTRICH to calculate objective function(s).
./run_mesh.sh
echo MESH finished.

## Checking if a MESH run completed by checking if Metrics_Out.txt is created.
## If MESH fails to run completely, the "BAD_Metrics_Out.txt" containing flag values of "-999.0" will replace "Metrics_Out.txt" file.
if [ -f ./Metrics_Out.txt ]; then
	echo 'Good'
else
  cp BAD_Metrics_Out.txt Metrics_Out.txt
  echo 'Bad'
fi

## Save files (in compact format) using parameter set number.
## This is only done for later use of the results if needed. 
## Ensure that you don't run out of space.
 num=$(cat Dummy.txt | grep -o '[0-9]*')
 cp ./results/MESH_output_streamflow.csv $root_dir/ost/OUTPUT/streamflows/flow_${num}.csv
 xz $root_dir/ost/OUTPUT/streamflows/flow_${num}.csv

pwd
echo OST_MESH Script Finished. Hurray!

